@@ -1,10 +1,12 @@
+# frozen_string_literal: true
+
 require "spec_helper"
 
 RSpec.describe Lumberjack::Device::Multi do
   let(:output_1) { StringIO.new }
   let(:output_2) { StringIO.new }
-  let(:device_1) { Lumberjack::Device::Writer.new(output_1, template: ":message") }
-  let(:device_2) { Lumberjack::Device::Writer.new(output_2, template: ":severity - :message") }
+  let(:device_1) { Lumberjack::Device::Writer.new(output_1, template: "{{message}}") }
+  let(:device_2) { Lumberjack::Device::Writer.new(output_2, template: "{{severity}} - {{message}}") }
   let(:device) { Lumberjack::Device::Multi.new(device_1, device_2) }
 
   let(:entry) { Lumberjack::LogEntry.new(Time.now, Logger::INFO, "test", "app", 100, {}) }
