@@ -1,6 +1,12 @@
+# frozen_string_literal: true
+
 require "spec_helper"
 
 RSpec.describe Lumberjack::Formatter::StringFormatter do
+  it "is registered as :string" do
+    expect(Lumberjack::FormatterRegistry.formatter(:string)).to be_a(Lumberjack::Formatter::StringFormatter)
+  end
+
   it "should format objects as string by calling their to_s method" do
     formatter = Lumberjack::Formatter::StringFormatter.new
     expect(formatter.call("abc")).to eq("abc")
